package com.ruoyi.ss.transferDetail.mapper;

import com.ruoyi.ss.transferDetail.domain.TransferDetail;
import com.ruoyi.ss.transferDetail.domain.TransferDetailQuery;
import com.ruoyi.ss.transferDetail.domain.TransferDetailVO;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 转账明细Mapper接口
 *
 * @author ruoyi
 * @date 2024-08-09
 */
public interface TransferDetailMapper
{
    /**
     * 查询转账明细
     *
     * @param detailId 转账明细主键
     * @return 转账明细
     */
    public TransferDetailVO selectTransferDetailByDetailId(Long detailId);

    /**
     * 查询转账明细列表
     *
     * @param query 转账明细
     * @return 转账明细集合
     */
    public List<TransferDetailVO> selectTransferDetailList(@Param("query")TransferDetailQuery query);

    /**
     * 新增转账明细
     *
     * @param transferDetail 转账明细
     * @return 结果
     */
    public int insertTransferDetail(TransferDetail transferDetail);

    /**
     * 修改转账明细
     *
     * @param transferDetail 转账明细
     * @return 结果
     */
    public int updateTransferDetail(@Param("data") TransferDetail transferDetail);

    /**
     * 删除转账明细
     *
     * @param detailId 转账明细主键
     * @return 结果
     */
    public int deleteTransferDetailByDetailId(Long detailId);

    /**
     * 批量删除转账明细
     *
     * @param detailIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTransferDetailByDetailIds(Long[] detailIds);

    /**
     * 批量新增
     */
    int batchInsert(@Param("list") List<TransferDetailVO> list);

    /**
     * 条件更新
     */
    int updateByQuery(@Param("data") TransferDetail data, @Param("query") TransferDetailQuery query);
}
